/*-------------------------------------------------------------------------+
| Copyright 2014 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.model.base.impl;

import org.fortiss.tooling.base.model.base.DerivedAnnotationBase;
import org.fortiss.tooling.base.model.element.IDerivedAnnotation;

/**
 * Static implementation for {@link DerivedAnnotationBase}.
 * 
 * @author diewald
 */
public class DerivedAnnotationBaseStaticImpl {

	/**
	 * Wrapper for returning derived values of {@link IDerivedAnnotation}s. If the user input is
	 * preferred by the concrete annotation, this function returns the user input if any is set.
	 * Otherwise it determines the calculated value, if the value can be calculated. If the value
	 * cannot be calculated, and a user input is given which is not preferred it is returned
	 * instead. If none of the previously mentioned cases applies, {@code null} is returned.
	 * 
	 * @param annotation
	 *            The annotation to which this wrapper shall be applied to.
	 * @return See above.
	 */
	public static <T> T getValue(IDerivedAnnotation<T> annotation) {
		T derivedValue = null;
		if(annotation.getUserAnnotatedValue() != null) {
			if(annotation.isUserAnnotatedValuePreferred()) {
				// User annotated value is available and preferred -> return it
				return annotation.getUserAnnotatedValue();
			}
			derivedValue = annotation.getDerivedValue();
			if(derivedValue == null) {
				// Derived value would be preferred, but it is not available -> return user
				// annotated value
				return annotation.getUserAnnotatedValue();
			}
		}

		// Use cached result of derived value if it is available
		return derivedValue != null ? derivedValue : annotation.getDerivedValue();
	}
}
