/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *     Alexander Diewald (fortiss GmbH) - backport to AF3 & Integration
 *                                        improvements
 *
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.control.treetableview;

import static java.util.Collections.emptyList;
import static java.util.stream.Collectors.toList;

import java.util.Collection;
import java.util.Comparator;
import java.util.function.Predicate;

/**
 * Base class for implementing tree content providers used in {@link DynamicTreeViewer} and
 * {@link DynamicTreeTableViewer}.
 */
public abstract class DynamicTreeContentProviderBase<T> {
	/** Returns the children of the given parent in the tree. */
	protected abstract Collection<? extends T> getChildren(T parent);

	/** Returns the filer predicate. */
	protected Predicate<Object> getFilterPredicate() {
		return (o) -> true;
	}

	/** Returns the sorter comparator. */
	protected Comparator<Object> getSortingComparator() {
		return (o1, o2) -> 0;
	}

	/** Returns the filtered children of the given element. */
	public final Collection<? extends T> getFilteredSortedChildren(T parent) {
		Collection<? extends T> l = getChildren(parent);
		if(l == null) {
			return emptyList();
		}
		return l.stream().filter(getFilterPredicate()).sorted(getSortingComparator())
				.collect(toList());
	}
}
