/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.jface;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

/**
 * Base implementation of a tree content provider that has an empty default
 * implementation for some methods. Some of the methods require implementation
 * almost always (e.g. {@link #getElements(Object)} and
 * {@link #getParent(Object)}), but for simple content providers the base
 * implementation is sufficient.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 69EC26B5D792413C0BB704A714756319
 */
public abstract class TreeContentProviderBase implements ITreeContentProvider {

	/**
	 * {@inheritDoc}
	 * <p>
	 * Default implementation returns null, which makes automatic expansion of
	 * externally set selection impossible.
	 */
	public Object getParent(Object inputElement) {
		return null;
	}

	/**
	 * {@inheritDoc}
	 * <p>
	 * Uses the result of {@link #getChildren(Object)} to determine result.
	 */
	public boolean hasChildren(Object inputElement) {
		Object[] children = getChildren(inputElement);
		return children != null && children.length > 0;
	}

	/**
	 * {@inheritDoc}
	 * <p>
	 * Just calls {@link #getChildren(Object)}.
	 */
	public Object[] getElements(Object inputElement) {
		return getChildren(inputElement);
	}

	/**
	 * {@inheritDoc}
	 * <p>
	 * Empty implementation.
	 */
	public void dispose() {
		// not needed
	}

	/**
	 * {@inheritDoc}
	 * <p>
	 * Empty implementation.
	 */
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// not needed
	}
}